==> haskell-asn1-types-0.3.2-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.2
id: asn1-types-0.3.2-2K0ANkYzFxWBu24WOGrxw8
key: asn1-types-0.3.2-2K0ANkYzFxWBu24WOGrxw8
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1-types
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
abi: b219252eeecac05eb5b77c9e9df6f77d
exposed: True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
import-dirs: /usr/lib/ghc-8.6.4/site-local/asn1-types-0.3.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/asn1-types-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/asn1-types-0.3.2
hs-libraries: HSasn1-types-0.3.2-2K0ANkYzFxWBu24WOGrxw8
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    hourglass-0.2.12-4Si5cuysh1XI8xL9F9SZUc
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.2-89-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.2
id: asn1-types-0.3.2-DLmgLG4DguzLHCJactuvzi
key: asn1-types-0.3.2-DLmgLG4DguzLHCJactuvzi
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1-types
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
abi: f2c9ac6275cce8ea9ee0e8b198c76580
exposed: True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
import-dirs: /usr/lib/ghc-8.6.4/site-local/asn1-types-0.3.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/asn1-types-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/asn1-types-0.3.2
hs-libraries: HSasn1-types-0.3.2-DLmgLG4DguzLHCJactuvzi
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    hourglass-0.2.12-6cegQbTCp2XGNMMF7vzGJo
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
